package App::dirstrata1 ;  
our $VERSION = '0.050' ; 
our $DATE = '2023-04-07T16:00+09:00' ; 

=encoding utf8

=head1 NAME

App::dirstrata1 -- Shows the longest directory branch paths (most apart each other) of a given directory.

=head1 SYNOPSIS

This module provides a Unix-like command `F<dirstrata1>'. 

=head1 DESCRIPTION

 dirstrata1 
 
 Options (selected): 
 
=head1 NOTE

=head1 SEE ALSO

  App::dirstrata -- gives minute hierarchial information about a directory using a triangular matrix.

=head1 AUTHOR

下野寿之 Toshiyuki SHIMONO <bin4tsv@gmail.com> The Institute of Statistical Mathematics, a visiting researcher. 

=head1 COPYRIGHT AND LICENSE

Copyright (c) 2016-2023 Toshiyuki SHIMONO. All rights reserved.
This program is free software; you can redistribute it and/or
modify it under the same terms as Perl itself.

=cut

1 ;
